#
# SPDX-FileCopyrightText: Copyright 2025 Siemens AG
# SPDX-License-Identifier: BSD-3-Clause
#
class _QuotesHandler:
    # List of quote characters to replace with the default replacement.
    quote_characters = [
        # Single quotes
        "\u2018",  # LEFT SINGLE QUOTATION MARK ‘
        "\u2019",  # RIGHT SINGLE QUOTATION MARK ’
        "\u201A",  # SINGLE LOW-9 QUOTATION MARK ‚
        "\u201B",  # SINGLE HIGH-REVERSED-9 QUOTATION MARK ‛
        "\u2032",  # PRIME (often used as an apostrophe) ′
        "\uFF07",  # FULLWIDTH APOSTROPHE ＇
        # Double quotes
        "\u201C",  # LEFT DOUBLE QUOTATION MARK “
        "\u201D",  # RIGHT DOUBLE QUOTATION MARK ”
        "\u201E",  # DOUBLE LOW-9 QUOTATION MARK „
        "\u201F",  # DOUBLE HIGH-REVERSED-9 QUOTATION MARK ‟
        "\u2033",  # DOUBLE PRIME ″
        "\u00AB",  # LEFT-POINTING DOUBLE ANGLE QUOTATION MARK «
        "\u00BB",  # RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK »
        "\uFF02",  # FULLWIDTH QUOTATION MARK ＂
    ]

    def normalize_quotes(self, input_string: str, replacement: str = "'") -> str:
        """
        Normalize a string by replacing various Unicode and ASCII quote characters
        with a single default quote character. By default, all quotes (both single and double)
        are mapped to the ASCII single quote.

        Args:
            input_string (str): The input text that potentially contains various quote characters.
            replacement (str, optional): The quote character replacement to use. Defaults to "'".

        Returns:
            str: The normalized text with all recognized quote characters replaced.
        """
        translation_map = {ord(char): replacement for char in self.quote_characters}
        normalized_input_string = input_string.translate(translation_map)
        return normalized_input_string



#
# SPDX-FileCopyrightText: Copyright 2025 Siemens AG
# SPDX-License-Identifier: BSD-3-Clause
#
from dataclasses import dataclass
from licenselynx.license_source import LicenseSource


@dataclass
class LicenseObject(object):
    """LicenseObject class represents a license with a canonical name and source."""

    id: str
    src: LicenseSource

    def is_spdx_identifier(self):
        """
        Checks if source of LicenseObject is SPDX.
        :return: True if source of LicenseObject is SPDX
        """
        return self.src == LicenseSource.SPDX

    def is_scancode_licensedb_identifier(self):
        """
        Checks if source of LicenseObject is ScanCode LicenseDB.
        :return: True if source of LicenseObject is ScanCode LicenseDB
        """
        return self.src == LicenseSource.SCANCODE_LICENSEDB

    def is_custom_identifier(self):
        """
        Checks if source of LicenseObject is custom.
        :return: True if source of LicenseObject is custom
        """
        return self.src == LicenseSource.CUSTOM



from enum import StrEnum


class LicenseSource(StrEnum):
    """Enum representing the source of a canonical identifier."""
    SPDX = "spdx"
    SCANCODE_LICENSEDB = "scancode-licensedb"
    CUSTOM = "custom"
